@@ -1,4 +1,10 @@
-class InAppPyValidationError(Exception):
+class InAppPyError(Exception):
+    """ Base class for all errors """
+
+    pass
+
+
+class InAppPyValidationError(InAppPyError):
     """ Base class for all validation errors """
 
     raw_response = None
